# Changelog

<!--next-version-placeholder-->

## v0.1.1 (2023-11-17)

### Fix

* Dependencies in setup.cfg ([`c76b124`](https://github.com/Stephen-RA-King/metabook/commit/c76b124b6b16f66346d234469d59a8c87e835ba0))

## v0.1.0 (2023-11-17)

### Feature

* Add additional cli arguments ([`ddcf831`](https://github.com/Stephen-RA-King/metabook/commit/ddcf8312612cc745bea6de92b704c949c77938ef))
* Add main function ([`df88ab6`](https://github.com/Stephen-RA-King/metabook/commit/df88ab6ba5d19889ac556bc8c6dfde58518c96b8))
* Add find_isbn_in_pdf function ([`4c370fc`](https://github.com/Stephen-RA-King/metabook/commit/4c370fc865d7903f5777e468aa426043cff16384))
* Add output function ([`4952811`](https://github.com/Stephen-RA-King/metabook/commit/49528115dd44d1d6329492432f574229993956e3))
* Add sanitize_isbn and normalize_filename ([`7c5b301`](https://github.com/Stephen-RA-King/metabook/commit/7c5b301d31cc56c0385b3d692985ec729a8cca56))
* Add render_template function ([`b99e1c2`](https://github.com/Stephen-RA-King/metabook/commit/b99e1c2860c8f178d1adceca29789fa1984d5383))
* Add write_metadata function ([`508579e`](https://github.com/Stephen-RA-King/metabook/commit/508579e87be3b412ea8acaef999b6a97c9fa63d4))
* Add update_filename function ([`6afa5ba`](https://github.com/Stephen-RA-King/metabook/commit/6afa5baab0b395ae289d4f175e3358613b0be146))
* Add find_book function ([`0fe0a66`](https://github.com/Stephen-RA-King/metabook/commit/0fe0a6638bb81675cbf1f9c4cddef5caec680adc))

### Fix

* Version numbers ([`17d7c60`](https://github.com/Stephen-RA-King/metabook/commit/17d7c602637ae419a6fc6d15337a90aa27c40726))

### Documentation

* Update readme ([`4d54b2a`](https://github.com/Stephen-RA-King/metabook/commit/4d54b2a21a8c9e118826984feb27010e68708558))

## 0.0.0 (2023-06-29)

### First Release of 'metabook'
